@@ -207,7 +207,7 @@ class Trean_Bookmarks
         /* Untag */
         $tagger = $GLOBALS['injector']->getInstance('Trean_Tagger');
         $tagger->replaceTags((string)$bookmark->id, array(), $GLOBALS['registry']->getAuth(), 'bookmark');
-        $GLOBALS['injector']->getInstance('Content_Objects_Mapper')
+        $GLOBALS['injector']->getInstance('Content_ObjectMapper')
             ->delete($bookmark->id, 'bookmark');
 
         /* @TODO delete from content index? */
